@@ -16,14 +16,14 @@ if THREAD_SAFE:
         conn = persist.connection()
         return conn
 else:
-    from DBUtils.SteadyDB import connect
-    def connection(*args, **kwds):
-        kwds['maxusage'] = False
-        return connect(MySQLdb, *args, **kwds)
+#    from DBUtils.SteadyDB import connect
+#    def connection(*args, **kwds):
+#        kwds['maxusage'] = False
+#        return connect(MySQLdb, *args, **kwds)
 
-#def connection(*arg,**kwds):
-#   conn=MySQLdb.connect(*arg,**kwds)
-#   return comm
+    def connection(*arg,**kwds):
+       conn=MySQLdb.connect(*arg,**kwds)
+       return conn
 
 
 class LogCursor(object):
@@ -106,7 +106,7 @@ class SqlFarm:
 
     def stop_log(self):
         if self._cursor is not None:
-            self._cursor = self._cursor.cursor
+            self._cursor = self._cursor._cursor
 
     def get_log(self, name):
         def sql_log(name, log):
